==> tagmemo_0_1.tar.gz: tagmemo/index.php <==
<?php
/**
* @package Page
*/

// ɬפʥե쵤˼पޤʤ
/**
* XOOPSѥեμ
*/
require_once '../../mainfile.php';
$myts =& MyTextSanitizer::getInstance();
$tag_id = empty($_GET["tag_id"]) ? "" :$_GET["tag_id"];
$condition = $tag_id;
$tag_id = explode(",",$tag_id);
$keyword = empty($_GET["query"]) ? "" :$_GET["query"];
//$keyword = $myts->addSlashes($keyword);
$condition .= $keyword;
$count = isset($xoopsModuleConfig['per_page']) ? $xoopsModuleConfig['per_page'] : 10;
$count = (strlen($condition)>0) ? 0 : $count;
//$search_from = empty($_GET["from"]) ? "sub" :$_GET["from"];
$start = empty($_GET["start"]) ? 0 : intval($_GET["start"]);
$tagmemo_handler =& xoops_getmodulehandler('tagmemo');

if(strlen($keyword)>0){
	$tagmemo_handler->search($keyword);
//	if($search_from=="all"){
		$tag_id  = array();
//	}
}

if(is_object($xoopsUser)){
	$uid = $xoopsUser->getVar("uid");
} else {
	$uid = 0;
}
	$tagmemo_handler->setUid($uid);
$memo_array =& $tagmemo_handler->getMemosArray($tag_id,$count,$start);
if(strlen($condition)>0){
	$tagmemo_query=true;
	$query_condition = $tagmemo_handler->getQueryCondition();
	$query_condition = stripslashes($query_condition );
	$query_condition = htmlspecialchars($query_condition );
	$tag_condition = $tagmemo_handler->getTagCondition();
	$tagmemo_related_tags = $tagmemo_handler->getRelatedTags();
}else{
	$tagmemo_query=false;
//	$tagmemo_block_recent_hide = true;
}
$xoopsOption['template_main'] = 'tagmemo_list.html';
// echo 'my uid =' . $xoopsUser->getVar("uid");
// إå񤯤ޤʤ
/**
* XOOPSΥƥץ졼ȤΥإå
*/
include XOOPS_ROOT_PATH.'/header.php';
$xoopsTpl->assign("memos", $memo_array);
if(strlen($condition)>0){
	$xoopsTpl->assign("query",true);
	$xoopsTpl->assign("rel_tags", $tagmemo_related_tags);
	$xoopsTpl->assign("query_condition", $query_condition);
	$xoopsTpl->assign("query_condition_url", urlencode($query_condition));
	$xoopsTpl->assign("tag_condition", $tag_condition);
}else{

	$xoopsTpl->assign("query",false);
	$maxcount = $tagmemo_handler->getMemoCount();
	include_once XOOPS_ROOT_PATH.'/class/pagenav.php';
	$nav = new XoopsPageNav($maxcount, $count, $start);
	$xoopsTpl->assign('pagenav', $nav->renderNav());
}

$xoopsTpl->assign('bookmarklet','javascript: tagmemo_quickform_script = document.createElement(\'script\'); tagmemo_quickform_script.src = \''.XOOPS_URL.'/modules/tagmemo/quickform.php\'; tagmemo_quickform_script.type = \'text/javascript\'; void(document.body.appendChild(tagmemo_quickform_script));');
$ff_plugin = isset($xoopsModuleConfig['ff_plugin']) ? $xoopsModuleConfig['ff_plugin'] : 0;
$xoopsTpl->assign('ff_plugin', $ff_plugin);

/**
* XOOPSΥƥץ졼ȤΥեå
*/
include(XOOPS_ROOT_PATH.'/footer.php');
?>

==> tagmemo_0.2.tar.gz: tagmemo/index.php <==
<?php
/**
* @package Page
*/

// ɬפʥե쵤˼पޤʤ
/**
* XOOPSѥեμ
*/
require_once '../../mainfile.php';
$myts =& MyTextSanitizer::getInstance();
$tag_id = empty($_GET["tag_id"]) ? "" :$_GET["tag_id"];
$condition = $tag_id;
$tag_id = explode(",",$tag_id);
$keyword = empty($_GET["query"]) ? "" :$_GET["query"];
//$keyword = $myts->addSlashes($keyword);
$condition .= $keyword;
$count = isset($xoopsModuleConfig['per_page']) ? $xoopsModuleConfig['per_page'] : 10;
$count = (strlen($condition)>0) ? 0 : $count;
//$search_from = empty($_GET["from"]) ? "sub" :$_GET["from"];
$start = empty($_GET["start"]) ? 0 : intval($_GET["start"]);
$tagmemo_handler =& xoops_getmodulehandler('tagmemo');

if(strlen($keyword)>0){
	$tagmemo_handler->search($keyword);
//	if($search_from=="all"){
		$tag_id  = array();
//	}
}

if(is_object($xoopsUser)){
	$uid = $xoopsUser->getVar("uid");
	$uname = $xoopsUser->getVar("uname");
} else {
	$uid = 0;
	$uname = "";
}
	$tagmemo_handler->setUid($uid);
$memo_array =& $tagmemo_handler->getMemosArray($tag_id,$count,$start);
if(strlen($condition)>0){
	$tagmemo_query=true;
	$query_condition = $tagmemo_handler->getQueryCondition();
	$query_condition = stripslashes($query_condition );
	$query_condition = htmlspecialchars($query_condition );
	$tag_condition = $tagmemo_handler->getTagCondition();
	$tagmemo_related_tags = $tagmemo_handler->getRelatedTags();
}else{
	$tagmemo_query=false;
//	$tagmemo_block_recent_hide = true;
}
$xoopsOption['template_main'] = 'tagmemo_list.html';
// echo 'my uid =' . $xoopsUser->getVar("uid");
// إå񤯤ޤʤ
/**
* XOOPSΥƥץ졼ȤΥإå
*/
include XOOPS_ROOT_PATH.'/header.php';
$xoopsTpl->assign("memos", $memo_array);

//version 
$xoopsTpl->assign("tagmemo_version", $xoopsModule->getInfo('version'));

// <head>ȥ
$_tmp = array();
if (!empty($tag_condition['detail']))
{
	foreach($tag_condition['detail'] as $_val)
	{
		$_tmp[] = $_val['string'];
	}
}
$_tmp = join("+",$_tmp);
$xoopsTpl->assign("xoops_pagetitle",$_tmp."-".$xoopsModule->name());

// ꥹȤΥݥåץå׻
$xoopsTpl->assign("taglist_popup",empty($xoopsModuleConfig['tagpopup_list'])? false : true);

if(strlen($condition)>0){
	$xoopsTpl->assign("query",true);
	$xoopsTpl->assign("rel_tags", $tagmemo_related_tags);
	$xoopsTpl->assign("query_condition", $query_condition);
	$xoopsTpl->assign("query_condition_url", urlencode($query_condition));
	$xoopsTpl->assign("tag_condition", $tag_condition);
}else{

	$xoopsTpl->assign("query",false);
	$maxcount = $tagmemo_handler->getMemoCount();
	include_once './class/pagenavi.php';
	$nav = new TagmemoPageNav($maxcount, $count, $start);
	$xoopsTpl->assign('pagenav', $nav->renderNav());
}

$xoopsTpl->assign('bookmarklet',"javascript:if(document.getElementById('tagmemo_scr'))document.body.removeChild(document.getElementById('tagmemo_scr'));(function(){var s=document.createElement('script');s.id='tagmemo_s';s.charset='EUC-JP';s.src='".XOOPS_URL."/modules/tagmemo/quickform.php?uid=".$uid."';document.body.appendChild(s)})();");
$ff_plugin = isset($xoopsModuleConfig['ff_plugin']) ? $xoopsModuleConfig['ff_plugin'] : 0;
$xoopsTpl->assign('ff_plugin', $ff_plugin);

/**
* XOOPSΥƥץ졼ȤΥեå
*/
include(XOOPS_ROOT_PATH.'/footer.php');
?>
